.. _wb_tempate-badges-placeholder:

===========
ant_connect
===========


    Add a short description here!


A longer description of your project goes here...


.. _pyscaffold-notes:


Note
====

This project has been set up using wb_template 2.0.1. For details and usage
information on PyScaffold see https://digital-solutions.docs.wbad.witteveenbos.com/wb_template/.
